Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DisabledRule ¶
type DisabledRule struct {
Name string
Source RuleSource
DisabledBy RuleSource
}
type LocalUpdatePlan ¶
type LocalUpdatePlan struct {
AfterSuccess []config.HookConfig
AfterFailure []config.HookConfig
Always []config.HookConfig
MatchedRules []MatchedRule
SkippedRules []RuleMatch
DisabledRules []DisabledRule
}
func NormalizeLocalUpdate ¶
func NormalizeLocalUpdate(in config.LocalUpdateHooksConfig) LocalUpdatePlan
NormalizeLocalUpdate treats hooks.update.local.after as an alias for after_success. Alias entries run before explicit after_success entries.
func ResolveLocalUpdatePlan ¶
func ResolveLocalUpdatePlan(local config.LocalUpdateHooksConfig, hookCtx Context, layers []config.ConfigLayer) LocalUpdatePlan
ResolveLocalUpdatePlan builds the local update hook execution plan from unconditional merged hooks plus named rules from ordered file layers.
func (LocalUpdatePlan) Empty ¶
func (p LocalUpdatePlan) Empty() bool
func (LocalUpdatePlan) SelectedPhases ¶
func (p LocalUpdatePlan) SelectedPhases(updateSucceeded bool) []PhaseHooks
type MatchedRule ¶
type MatchedRule struct {
Name string
Source RuleSource
AfterSuccess []config.HookConfig
AfterFailure []config.HookConfig
Always []config.HookConfig
}
type PhaseHooks ¶
type PhaseHooks struct {
Phase Phase
Hooks []config.HookConfig
}
type Result ¶
type Result struct {
Phase Phase
Hook config.HookConfig
Name string
Command string
Dir string
Output string
ExitCode int
Duration time.Duration
Err error
Timeout bool
}
func (Result) DisplayName ¶
type RuleMatch ¶
type RuleMatch struct {
Name string
Source RuleSource
Reason string
}
type RuleSource ¶
type RuleSource struct {
Scope config.ConfigLayerScope
Path string
BaseDir string
Order int
}
Click to show internal directories.
Click to hide internal directories.